@@ -512,6 +512,12 @@ if _settingsManager is None:
     print "Could not load the settings manager. Exiting."
     sys.exit(1)
 
+from event_manager import EventManager
+_eventManager = EventManager()
+
+from script_manager import ScriptManager
+_scriptManager = ScriptManager()
+
 try:
     # If we don't have an active desktop, we will get a RuntimeError.
     import mouse_review
@@ -542,8 +548,8 @@ from input_event import KeyboardEvent
 from input_event import MouseButtonEvent
 from input_event import keyEventToString
 
+import gc
 if settings.debugMemoryUsage:
-    import gc
     gc.set_debug(gc.DEBUG_UNCOLLECTABLE
                  | gc.DEBUG_COLLECTABLE
                  | gc.DEBUG_INSTANCES
@@ -569,90 +575,21 @@ _orcaModifiers = settings.DESKTOP_MODIFIER_KEYS + settings.LAPTOP_MODIFIER_KEYS
 _capsLockCleared = False
 _restoreOrcaKeys = False
 
-########################################################################
-#                                                                      #
-# METHODS FOR HANDLING PRESENTATION MANAGERS                           #
-#                                                                      #
-# A presentation manager is what reacts to AT-SPI object events as     #
-# well as user input events (keyboard and Braille) to present info     #
-# to the user.                                                         #
-#                                                                      #
-########################################################################
-
-# The known presentation managers (set up in start())
-#
-_PRESENTATION_MANAGERS = None
-
-# The current presentation manager, which is an index into the
-# _PRESENTATION_MANAGERS list.
-#
-_currentPresentationManager = -1
-
-def _switchToPresentationManager(index):
-    """Switches to the given presentation manager.
-
-    Arguments:
-    - index: an index into _PRESENTATION_MANAGERS
-    """
-
-    global _currentPresentationManager
-
-    if _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].deactivate()
-
-    _currentPresentationManager = index
-
-    # Wrap the presenter index around.
-    #
-    if _currentPresentationManager >= len(_PRESENTATION_MANAGERS):
-        _currentPresentationManager = 0
-    elif _currentPresentationManager < 0:
-        _currentPresentationManager = len(_PRESENTATION_MANAGERS) - 1
-
-    _PRESENTATION_MANAGERS[_currentPresentationManager].activate()
-
-def _switchToNextPresentationManager(script=None, inputEvent=None):
-    """Switches to the next presentation manager.
-
-    Arguments:
-    - inputEvent: the InputEvent instance that caused this to be called.
-
-    Returns True indicating the event should be consumed.
-    """
-
-    _switchToPresentationManager(_currentPresentationManager + 1)
-    return True
-
-def getScriptForApp(app):
-    """Get the script for the given application object from the current
-    presentation manager.
-
-    Arguments:
-    - app: An application accessible.
-
-    Returns a Script instance.
-    """
-
-    script = None
-    if _currentPresentationManager >= 0:
-        script = \
-            _PRESENTATION_MANAGERS[_currentPresentationManager].getScript(app)
-    return script
-
 ########################################################################
 #                                                                      #
 # METHODS TO HANDLE APPLICATION LIST AND FOCUSED OBJECTS               #
 #                                                                      #
 ########################################################################
 
-def setLocusOfFocus(event, obj, notifyPresentationManager=True, force=False):
+def setLocusOfFocus(event, obj, notifyScript=True, force=False):
     """Sets the locus of focus (i.e., the object with visual focus) and
-    notifies the current presentation manager of the change.
+    notifies the script of the change should the script wish to present
+    the change to the user.
 
     Arguments:
     - event: if not None, the Event that caused this to happen
     - obj: the Accessible with the new locus of focus.
-    - notifyPresentationManager: if True, propagate this event
+    - notifyScript: if True, propagate this event
     - force: if True, don't worry if this is the same object as the
       current locusOfFocus
     """
@@ -665,8 +602,13 @@ def setLocusOfFocus(event, obj, notifyPresentationManager=True, force=False):
     if event and event.source and \
        event.host_application and orca_state.activeScript:
         currentApp = orca_state.activeScript.app
-        if currentApp != event.host_application and \
-           currentApp != event.source.getApplication():
+        try:
+            appList = [event.host_application, event.source.getApplication()]
+        except LookupError:
+            appList = []
+            debug.println(debug.LEVEL_SEVERE,
+                           "orca.setLocusOfFocus() application LookupError")
+        if not currentApp in appList:
             return
 
     oldLocusOfFocus = orca_state.locusOfFocus
@@ -710,29 +652,9 @@ def setLocusOfFocus(event, obj, notifyPresentationManager=True, force=False):
             debug.println(debug.LEVEL_FINE,
                           "                event=None")
 
-    if notifyPresentationManager and _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].\
-            locusOfFocusChanged(event,
-                                oldLocusOfFocus,
-                                orca_state.locusOfFocus)
-
-def visualAppearanceChanged(event, obj):
-    """Called (typically by scripts) when the visual appearance of an object
-    changes and notifies the current presentation manager of the change.  This
-    method should not be called for objects whose visual appearance changes
-    solely because of focus -- setLocusOfFocus is used for that.  Instead, it
-    is intended mostly for objects whose notional 'value' has changed, such as
-    a checkbox changing state, a progress bar advancing, a slider moving, text
-    inserted, caret moved, etc.
-
-    Arguments:
-    - event: if not None, the Event that caused this to happen
-    - obj: the Accessible whose visual appearance changed.
-    """
-
-    if _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].\
-            visualAppearanceChanged(event, obj)
+    if notifyScript and orca_state.activeScript:
+        orca_state.activeScript.locusOfFocusChanged(
+            event, oldLocusOfFocus, orca_state.locusOfFocus)
 
 def _onChildrenChanged(e):
     """Tracks children-changed events on the desktop to determine when
@@ -856,11 +778,6 @@ def exitListShortcutsMode(self, inputEvent=None):
 #                                                                      #
 # METHODS FOR PRE-PROCESSING AND MASSAGING KEYBOARD EVENTS.            #
 #                                                                      #
-# All keyboard events are funnelled through here first.  Orca itself   #
-# might have global keybindings (e.g., to switch between presenters),  #
-# but it will typically pass the event onto the currently active       #
-# active presentation manager.                                         #
-#                                                                      #
 ########################################################################
 
 # Keybindings that Orca itself cares about.
@@ -1053,9 +970,18 @@ def keyEcho(event):
     # If this keyboard event was for an object like a password text
     # field, then don't echo it.
     #
-    if orca_state.locusOfFocus \
-        and (orca_state.locusOfFocus.getRole() == pyatspi.ROLE_PASSWORD_TEXT):
+    try:
+        role = orca_state.locusOfFocus.getRole()
+    except LookupError:
+        debug.println(debug.LEVEL_SEVERE,
+                      "orca.keyEcho() - locusOfFocus no longer exists")
+        setLocusOfFocus(None, None, False)
         return False
+    except:
+        pass
+    else:
+        if role == pyatspi.ROLE_PASSWORD_TEXT:
+            return False
 
     event_string = event.event_string
     debug.println(debug.LEVEL_FINEST,
@@ -1231,9 +1157,9 @@ def _processKeyboardEvent(event):
     """The primary key event handler for Orca.  Keeps track of various
     attributes, such as the lastInputEvent.  Also calls keyEcho as well
     as any local keybindings before passing the event on to the active
-    presentation manager.  This method is called synchronously from the
-    AT-SPI registry and should be performant.  In addition, it
-    must return True if it has consumed the event (and False if not).
+    script.  This method is called synchronously from the AT-SPI registry
+    and should be performant.  In addition, it must return True if it has
+    consumed the event (and False if not).
 
     Arguments:
     - event: an AT-SPI DeviceEvent
@@ -1369,9 +1295,8 @@ def _processKeyboardEvent(event):
             if (not consumed):
                 consumed = _keyBindings.consumeKeyboardEvent( \
                   None, keyboardEvent)
-            if (not consumed) and (_currentPresentationManager >= 0):
-                consumed = _PRESENTATION_MANAGERS[_currentPresentationManager].\
-                           processKeyboardEvent(keyboardEvent)
+            if (not consumed):
+                consumed = _eventManager.processKeyboardEvent(keyboardEvent)
             if (not consumed) and settings.learnModeEnabled:
                 if keyboardEvent.type == pyatspi.KEY_PRESSED_EVENT:
                     clickCount = orca_state.activeScript.getClickCount()
@@ -1437,8 +1362,7 @@ def _processBrailleEvent(event):
     orca_state.lastInputEvent = event
 
     try:
-        consumed = _PRESENTATION_MANAGERS[_currentPresentationManager].\
-                   processBrailleEvent(event)
+        consumed = _eventManager.processBrailleEvent(event)
     except:
         debug.printException(debug.LEVEL_SEVERE)
 
@@ -1536,7 +1460,7 @@ def _restoreXmodmap(keyList=[]):
 
     os.system("echo '%s' | xmodmap - > /dev/null 2>&1" % "\n".join(toRestore))
 
-def loadUserSettings(script=None, inputEvent=None):
+def loadUserSettings(script=None, inputEvent=None, isProfileLoad=False):
     """Loads (and reloads) the user settings module, reinitializing
     things such as speech if necessary.
 
@@ -1559,10 +1483,7 @@ def loadUserSettings(script=None, inputEvent=None):
     braille.shutdown()
     mag.shutdown()
 
-    if _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].deactivate()
-
-    time.sleep(1)
+    _scriptManager.deactivate()
 
     reloaded = False
     if _userSettings:
@@ -1596,7 +1517,7 @@ def loadUserSettings(script=None, inputEvent=None):
     if settings.enableSpeech:
         try:
             speech.init()
-            if reloaded:
+            if reloaded and not isProfileLoad:
                 # Translators: there is a keystroke to reload the user
                 # preferences.  This is a spoken prompt to let the user
                 # know when the preferences has been reloaded.
@@ -1652,8 +1573,8 @@ def loadUserSettings(script=None, inputEvent=None):
     _storeXmodmap(_orcaModifiers)
     _createOrcaXmodmap()
 
-    if _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].activate()
+    _scriptManager.activate()
+    _eventManager.activate()
 
     showMainWindowGUI()
 
@@ -1918,15 +1839,13 @@ def getListOfShortcuts(typeOfShortcuts):
     Returns a list of shortcuts; depending on the value of argument.
     """
 
-    import default
-
     numShortcuts = len(orca_state.listOfShortcuts)
     shortcuts = []
     shortcut = ""
     clickCount = ""
     brlKeyName = ""     
     brlHandler = None
-    defScript = default.Script(None)
+    defScript = _scriptManager.getDefaultScript()
     defKeyBindings = defScript.getKeyBindings()
     defBrlBindings = defScript.getBrailleBindings()
     kbindings = keybindings.KeyBindings()
@@ -2094,8 +2013,6 @@ def start(registry):
     """Starts Orca.
     """
 
-    global _PRESENTATION_MANAGERS
-
     if not _initialized:
         init(registry)
 
@@ -2105,13 +2022,6 @@ def start(registry):
         signal.signal(signal.SIGALRM, settings.timeoutCallback)
         signal.alarm(settings.timeoutTime)
 
-    if not _PRESENTATION_MANAGERS:
-        import focus_tracking_presenter
-        _PRESENTATION_MANAGERS = \
-            [focus_tracking_presenter.FocusTrackingPresenter()]
-
-    _switchToPresentationManager(0) # focus_tracking_presenter
-
     if settings.timeoutCallback and (settings.timeoutTime > 0):
         signal.alarm(0)
 
@@ -2168,8 +2078,8 @@ def shutdown(script=None, inputEvent=None):
     pyatspi.Registry.deregisterEventListener(_onMouseButton,
                                              "mouse:button")
 
-    if _currentPresentationManager >= 0:
-        _PRESENTATION_MANAGERS[_currentPresentationManager].deactivate()
+    _eventManager.deactivate()
+    _scriptManager.deactivate()
 
     # Shutdown all the other support.
     #
@@ -2253,6 +2163,17 @@ def multipleOrcas():
     ppid = os.getppid()
     return len(filter(lambda p: p not in [pid, ppid], orcas)) > 0
 
+def cleanupGarbage():
+    """Cleans up garbage on the heap."""
+    gc.collect()
+    for obj in gc.garbage:
+        try:
+            if isinstance(obj, pyatspi.Accessibility.Accessible):
+                gc.garbage.remove(obj)
+                obj.__del__()
+        except:
+            pass
+
 def main():
     """The main entry point for Orca.  The exit codes for Orca will
     loosely be based on signals, where the exit code will be the
